@@ -21,7 +21,7 @@ import pdb # pdb.set_trace()
 
 
 # Set version
-version="0.2.0"
+version="0.3.0"
 
 
 # Platform
@@ -89,14 +89,21 @@ Version: %s
 Files types:
 
     - %s: Source files to be downlaoded.
-    - (*)%s: shell script that will be executed in a docker build step.
-    - (*)%s: Source file that will be included only in the build process.
-    - (*)%s: Source file that will be included to the docker container execution and build process. All @{*} variables will be replaced with the variable value.
-    - (*)%s: Entrypoint shell script.
-    - (*)%s: Append dockerfile raw layers.
 
+    - (*)%s: Executed script in a docker build step.
 
-''' % (version, short_description, source_file_extension, exec_extension, image_export_source_extension, build_export_source_extension, entrypoint_extension, dokerfile_append_extension)
+    - (*)%s: Source file included only in the build process.
+
+    - (*)%s: Source file included in the container and build process.
+
+    - (*)%s: Entrypoint.
+
+    - (*)%s: Dockerfile raw append.
+
+    Note: All @{*} variables will be replaced with the variable value before adding '(*)%s', '(*)%s' and '(*)%s'.
+''' % (version, short_description, source_file_extension, exec_extension, image_export_source_extension,
+        build_export_source_extension, entrypoint_extension, dokerfile_append_extension, image_export_source_extension,
+        build_export_source_extension, entrypoint_extension)
 
 # Dockerfile template
 docker_file_template = '''
@@ -136,7 +143,7 @@ IMAGE_SOURCE_DIR="%s"
 ENTRYPOINT_DIR="%s"
 
 LABEL_COLOR=" \033[94m"
-TRACE_COLOR="\033[90m"
+TRACE_COLOR="\033[0m"
 ERROR_COLOR="\033[91m"
 SUCCESS_COLOR="\033[1;32m"
 REMOVE_FORMAT="\033[0m"
@@ -199,11 +206,18 @@ replaceVariables(){
     fi
 }
 
+CRLF_2_LF(){
+    FILE="${1}"
+    sed -i 's/\\r$//' "${FILE}"
+}
+
 buildStep(){
 
     mv "${EXEC_PATH}" "${CURRENT_WORKING_PATH}"
 
     cd "${CURRENT_WORKING_PATH}"
+
+    CRLF_2_LF "${EXEC_FILE}"
     chmod u+x "${EXEC_FILE}"
 
     # exec
@@ -240,6 +254,7 @@ buildSource(){
 
     # Repace variables
     replaceVariables "${FILE}"
+    CRLF_2_LF "${FILE}"
 
     # Copiar
     cp "${FILE}" "${BUILD_SOURCE_DIR}/${BUILD_SOURCE_NAME}"
@@ -284,6 +299,7 @@ imageSource(){
 
     # Repace variables
     replaceVariables "${FILE}"
+    CRLF_2_LF "${FILE}"
 
     # Copiar
     cp "${FILE}" "${IMAGE_SOURCE_DIR}/${IMAGE_SOURCE_NAME}"
@@ -320,6 +336,7 @@ entryPoint(){
 
     # Repace variables
     replaceVariables "${FILE}"
+    CRLF_2_LF "${FILE}"
 
     # Copiar
     cp "${FILE}" "${ENTRYPOINT_DIR}/${ENTRYPOINT_NAME}"
@@ -1223,6 +1240,13 @@ def main(argv=sys.argv[1:]):
                 else:
                     log.warning("unknown file type '%s'" % docker_build_file)
 
+            # Add version tag
+            version_info="\n"
+            version_info+="#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n"
+            version_info+="# Dockerfile content autogenerated by DockerBuild v%s\n" % version
+            version_info+="# https://pypi.org/project/DockerBuild/\n"
+            version_info+="#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n"
+            docker_file_content=version_info+docker_file_content
 
             # Remplace generated content
             image_info.dockerfile_content = image_info.dockerfile_content.replace(image_generate_code_tag, docker_file_content)
